@@ -1,6 +1,6 @@
 /***************************************************************************
  *   Copyright (C) 2012 Aurélien Gâteau <agateau@kde.org>                  *
- *   Copyright (C) 2013-2014 by Eike Hein <hein@kde.org>                   *
+ *   Copyright (C) 2013-2015 by Eike Hein <hein@kde.org>                   *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -21,107 +21,89 @@
 #ifndef APPSMODEL_H
 #define APPSMODEL_H
 
-#include "abstractentry.h"
 #include "abstractmodel.h"
+#include "appentry.h"
 
-#include <KService>
 #include <KServiceGroup>
 
-class AppsModel;
-class MenuEntryEditor;
+class AppGroupEntry;
 
-class QQmlPropertyMap;
 class QTimer;
 
-class AppGroupEntry : public AbstractGroupEntry
-{
-    public:
-        AppGroupEntry(KServiceGroup::Ptr group, AppsModel *parentModel,
-            bool flat, int appNameFormat);
-};
-
-class AppEntry : public AbstractEntry
-{
-    public:
-        AppEntry(KService::Ptr service, const QString &name);
-
-        EntryType type() const { return RunnableType; }
-
-        KService::Ptr service() const { return m_service; }
-
-    private:
-        KService::Ptr m_service;
-};
-
 class AppsModel : public AbstractModel
 {
     Q_OBJECT
 
     Q_PROPERTY(bool flat READ flat WRITE setFlat NOTIFY flatChanged)
+    Q_PROPERTY(bool showSeparators READ showSeparators WRITE setShowSeparators NOTIFY showSeparatorsChanged)
     Q_PROPERTY(int appNameFormat READ appNameFormat WRITE setAppNameFormat NOTIFY appNameFormatChanged)
-    Q_PROPERTY(QObject* appletInterface READ appletInterface WRITE setAppletInterface NOTIFY appletInterfaceChanged);
 
     public:
-        enum NameFormat {
-            NameOnly = 0,
-            GenericNameOnly,
-            NameAndGenericName,
-            GenericNameAndName
-        };
-
-        explicit AppsModel(const QString &entryPath = QString(), bool flat = false, QObject *parent = 0);
+        explicit AppsModel(const QString &entryPath = QString(), bool flat = false, bool separators = true, QObject *parent = 0);
+        explicit AppsModel(const QList<AbstractEntry *> entryList, bool deleteEntriesOnDestruction, QObject *parent = 0);
         ~AppsModel();
 
+        QString description() const;
+        void setDescription(const QString &text);
+
         virtual QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const;
 
+        QModelIndex index(int row, int column, const QModelIndex &parent = QModelIndex()) const;
+
         int rowCount(const QModelIndex &parent = QModelIndex()) const;
 
         Q_INVOKABLE virtual bool trigger(int row, const QString &actionId, const QVariant &argument);
 
         Q_INVOKABLE AbstractModel *modelForRow(int row);
 
+        int separatorCount() const;
+
         bool flat() const;
         void setFlat(bool flat);
 
+        bool showSeparators() const;
+        void setShowSeparators(bool showSeparators);
+
         int appNameFormat() const;
         void setAppNameFormat(int format);
 
         QStringList hiddenEntries() const;
 
-        QObject *appletInterface() const;
-
-        static QString nameFromService(const KService::Ptr service, NameFormat nameFormat);
-
-    public Q_SLOTS:
-        void setAppletInterface(QObject *appletInterface);
+        void entryChanged(AbstractEntry *entry);
 
     Q_SIGNALS:
-        void refreshing() const;
+        void cleared() const;
         void flatChanged() const;
+        void showSeparatorsChanged() const;
         void appNameFormatChanged() const;
-        void appletInterfaceChanged(QObject *appletInterface) const;
-        void hiddenEntriesChanged();
+        void hiddenEntriesChanged() const;
 
     protected Q_SLOTS:
         virtual void refresh();
 
+    protected:
+        void refreshInternal();
+
+        QList<AbstractEntry *> m_entryList;
+        bool m_deleteEntriesOnDestruction;
+        int m_separatorCount;
+        bool m_showSeparators;
+
     private Q_SLOTS:
         void checkSycocaChanges(const QStringList &changes);
-        void childHiddenEntriesChanged();
-
-    protected:
-        QList<AbstractEntry *> m_entryList;
 
     private:
         void processServiceGroup(KServiceGroup::Ptr group);
-        QQmlPropertyMap *appletConfig() const;
+        void sortEntries();
 
+        QString m_description;
         QString m_entryPath;
+        bool m_staticEntryList;
         QTimer *m_changeTimer;
         bool m_flat;
-        NameFormat m_appNameFormat;
+        bool m_sortNeeded;
+        AppEntry::NameFormat m_appNameFormat;
         QStringList m_hiddenEntries;
-        QObject *m_appletInterface;
         static MenuEntryEditor *m_menuEntryEditor;
 };
 
