@@ -26,8 +26,10 @@
 #include <KRunner/AbstractRunner>
 #include <KRunner/RunnerManager>
 
-RunnerModel::RunnerModel(QObject *parent) : QAbstractListModel(parent),
-    m_runnerManager(0)
+RunnerModel::RunnerModel(QObject *parent) : QAbstractListModel(parent)
+, m_favoritesModel(0)
+, m_runnerManager(0)
+, m_deleteWhenEmpty(false)
 {
     QHash<int, QByteArray> roles;
     roles.insert(Qt::DisplayRole, "display");
@@ -43,6 +45,40 @@ RunnerModel::~RunnerModel()
 {
 }
 
+AbstractModel *RunnerModel::favoritesModel() const
+{
+    return m_favoritesModel;
+}
+
+void RunnerModel::setFavoritesModel(AbstractModel *model)
+{
+    if (m_favoritesModel != model) {
+        m_favoritesModel = model;
+
+        clear();
+
+        if (!m_query.isEmpty()) {
+            m_queryTimer.start();
+        }
+
+        emit favoritesModelChanged();
+    }
+}
+
+bool RunnerModel::deleteWhenEmpty() const
+{
+    return m_deleteWhenEmpty;
+}
+
+void RunnerModel::setDeleteWhenEmpty(bool deleteWhenEmpty)
+{
+    if (m_deleteWhenEmpty != deleteWhenEmpty) {
+        m_deleteWhenEmpty = deleteWhenEmpty;
+
+        emit deleteWhenEmptyChanged();
+    }
+}
+
 QVariant RunnerModel::data(const QModelIndex &index, int role) const
 {
     if (!index.isValid() || index.row() >= m_models.count()) {
@@ -146,7 +182,14 @@ void RunnerModel::matchesChanged(const QList<Plasma::QueryMatch> &matches)
         RunnerMatchesModel *matchesModel = m_models.at(row);
         QList<Plasma::QueryMatch> matches = matchesForRunner.take(matchesModel->runnerId());
 
-        matchesModel->setMatches(matches);
+        if (m_deleteWhenEmpty && matches.isEmpty()) {
+            beginRemoveRows(QModelIndex(), row, row);
+            m_models.removeAt(row);
+            delete matchesModel;
+            endRemoveRows();
+        } else {
+            matchesModel->setMatches(matches);
+        }
     }
 
     // At this point, matchesForRunner contains only matches for runners which
