@@ -34,6 +34,7 @@
 #include <QTimer>
 
 #include <KAuthorized>
+#include <KDesktopFile>
 #include <KFileItem>
 #include <KLocalizedString>
 #include <KRun>
@@ -225,7 +226,7 @@ void Backend::activateWindow(int winId)
     KWindowSystem::forceActiveWindow(winId);
 }
 
-void Backend::closeWindow(int winId)
+void Backend::closeByWinId(int winId)
 {
     TaskManager::AbstractGroupableItem *item = m_groupManager->rootGroup()->getMemberByWId(winId);
 
@@ -234,6 +235,15 @@ void Backend::closeWindow(int winId)
     }
 }
 
+void Backend::closeByItemId(int itemId)
+{
+    TaskManager::AbstractGroupableItem *item = m_groupManager->rootGroup()->getMemberById(itemId);
+
+    if (item) {
+        item->close();
+    }
+}
+
 void Backend::launchNewInstance(int id)
 {
     TaskManager::AbstractGroupableItem* item = m_groupManager->rootGroup()->getMemberById(id);
@@ -517,3 +527,16 @@ void Backend::presentWindows(int groupParentId)
         KWindowEffects::presentWindows(m_taskManagerItem->window()->winId(), QList<WId>::fromSet(item->winIds()));
     }
 }
+
+void Backend::urlDropped(const QUrl& url)
+{
+    if (!url.isValid() || !url.isLocalFile()) {
+        return;
+    }
+
+    KDesktopFile desktopFile(url.toLocalFile());
+
+    if (desktopFile.hasApplicationType()) {
+        m_groupManager->addLauncher(url);
+    }
+}
