@@ -45,6 +45,14 @@ static const char LIST_SEPARATOR_LM[] = ",";
 
 static const char REL_SESSION_FILE_PATH[] = "/keyboard/session/layout_memory.xml";
 
+static bool isDefaultLayoutConfig(const LayoutSet &layout, const QList<LayoutUnit> &defaultLayouts)
+{
+    if (defaultLayouts.isEmpty() || layout.layouts != defaultLayouts || layout.currentLayout != defaultLayouts.first()) {
+        return false;
+    }
+    return true;
+}
+
 QString LayoutMemoryPersister::getLayoutMapAsString()
 {
 	if( ! canPersist() )
@@ -66,6 +74,10 @@ QString LayoutMemoryPersister::getLayoutMapAsString()
 	}
 	else {
 		foreach(const QString& key , layoutMemory.layoutMap.keys()) {
+			if (isDefaultLayoutConfig(layoutMemory.layoutMap[key], layoutMemory.keyboardConfig.getDefaultLayouts())) {
+				continue;
+			}
+
 			QDomElement item = doc.createElement(ITEM_NODE);
 			item.setAttribute(OWNER_KEY_ATTRIBUTE, key);
 			item.setAttribute(CURRENT_LAYOUT_ATTRIBUTE, layoutMemory.layoutMap[key].currentLayout.toString());
@@ -85,39 +97,25 @@ QString LayoutMemoryPersister::getLayoutMapAsString()
 	return doc.toString();
 }
 
-static bool isRestoreSession()
-{
-    KConfigGroup c(KSharedConfig::openConfig("ksmserverrc", KConfig::NoGlobals), "General");
-    qCDebug(KCM_KEYBOARD) << "loginMode:" << c.readEntry("loginMode");
-    QString loginMode = c.readEntry("loginMode");
-    return loginMode != "default" && loginMode != "restoreSavedSession";	// we don't know how to restore saved session - only previous one
-}
-
 bool LayoutMemoryPersister::save()
 {
-	if( isRestoreSession() ) {
-        QFileInfo fileInfo(QStandardPaths::writableLocation(QStandardPaths::DataLocation) + REL_SESSION_FILE_PATH);
+    QFileInfo fileInfo(QStandardPaths::writableLocation(QStandardPaths::DataLocation) + REL_SESSION_FILE_PATH);
 
-        QDir baseDir(fileInfo.absoluteDir());
-        if( ! baseDir.exists() ) {
-            if( ! QDir().mkpath(baseDir.absolutePath()) ) {
-                qWarning() << "Failed to create directory" << baseDir.absolutePath();
-            }
+    QDir baseDir(fileInfo.absoluteDir());
+    if( ! baseDir.exists() ) {
+        if( ! QDir().mkpath(baseDir.absolutePath()) ) {
+            qWarning() << "Failed to create directory" << baseDir.absolutePath();
         }
-
-        QFile file(fileInfo.absoluteFilePath());
-    	return saveToFile(file);
     }
-    return false;
+
+    QFile file(fileInfo.absoluteFilePath());
+    return saveToFile(file);
 }
 
 bool LayoutMemoryPersister::restore()
 {
-	if( isRestoreSession() ) {
-        QFile file(QStandardPaths::writableLocation(QStandardPaths::DataLocation) + REL_SESSION_FILE_PATH);
-    	return restoreFromFile(file);
-    }
-    return false;
+    QFile file(QStandardPaths::writableLocation(QStandardPaths::DataLocation) + REL_SESSION_FILE_PATH);
+    return restoreFromFile(file);
 }
 
 
