@@ -24,7 +24,7 @@
 
 #include <KIO/NetAccess>
 #include <KMessageBox>
-#include <KIcon>
+#include <QIcon>
 #include <KLocale>
 #include <KGlobalSettings>
 #include <KConfig>
@@ -54,7 +54,7 @@ KNetAttach::KNetAttach( QWidget* parent )
     connect(_createIcon, SIGNAL(toggled(bool)), this, SLOT(updateFinishButtonText(bool)));
     connect( this, SIGNAL(helpRequested()), this, SLOT(slotHelpClicked()) );
     connect( this, SIGNAL(currentIdChanged(int)), this, SLOT(slotPageChanged(int)) );
-    setWindowIcon(KIcon("knetattach"));
+    setWindowIcon(QIcon::fromTheme("knetattach"));
     setOption(HaveHelpButton, true);
     //setResizeMode(Fixed); FIXME: make the wizard fixed-geometry
     button(FinishButton)->setEnabled(false);
@@ -90,13 +90,13 @@ void KNetAttach::setInformationText( const QString &type )
 {
     QString text;
 
-    if (type=="WebFolder") {
+    if (type==QLatin1String("WebFolder")) {
 	text = i18n("Enter a name for this <i>WebFolder</i> as well as a server address, port and folder path to use and press the <b>Save & Connect</b> button.");
-    } else if (type=="Fish") {
+    } else if (type==QLatin1String("Fish")) {
 	text = i18n("Enter a name for this <i>Secure shell connection</i> as well as a server address, port and folder path to use and press the <b>Save & Connect</b> button.");
-    } else if (type=="FTP") {
+    } else if (type==QLatin1String("FTP")) {
         text = i18n("Enter a name for this <i>File Transfer Protocol connection</i> as well as a server address and folder path to use and press the <b>Save & Connect</b> button.");
-    } else if (type=="SMB") {
+    } else if (type==QLatin1String("SMB")) {
         text = i18n("Enter a name for this <i>Microsoft Windows network drive</i> as well as a server address and folder path to use and press the <b>Save & Connect</b> button.");
     }
 
@@ -355,4 +355,3 @@ void KNetAttach::updateFinishButtonText(bool save)
 }
 
 // vim: ts=8 sw=4 noet
-#include "knetattach.moc"
